@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -37,6 +38,7 @@
 
 #include <tools/diagnose_ex.h>
 #include <tools/string.hxx>
+#include <sal/macros.h>
 
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
@@ -69,6 +71,7 @@
 #include <editeng/flstitem.hxx>
 #include <editeng/akrnitem.hxx>
 #include <editeng/colritem.hxx>
+#include <editeng/justifyitem.hxx>
 #include <svx/drawitem.hxx>
 #include <editeng/twolinesitem.hxx>
 #include <editeng/charreliefitem.hxx>
@@ -550,7 +553,7 @@ namespace
                                 ,{ITEMID_LANGUAGE_ASIAN,PROPERTY_CHARLOCALEASIAN}
                                 ,{ITEMID_LANGUAGE_COMPLEX,PROPERTY_CHARLOCALECOMPLEX}
         };
-        for(size_t k = 0; k < sizeof(pItems)/sizeof(pItems[0]);++k)
+        for(size_t k = 0; k < SAL_N_ELEMENTS(pItems);++k)
         {
             if ( SFX_ITEM_SET == _rItemSet.GetItemState( pItems[k].nWhich,sal_True,&pItem) && pItem->ISA(SvxLanguageItem))
             {
@@ -705,7 +708,7 @@ bool openCharDialog( const uno::Reference<report::XReportControlFormat >& _rxRep
 
     };
 
-    OSL_ASSERT((sizeof(pDefaults)/sizeof(pDefaults[0])) == (sizeof(aItemInfos)/sizeof(aItemInfos[0])));
+    OSL_ASSERT((SAL_N_ELEMENTS(pDefaults)) == (SAL_N_ELEMENTS(aItemInfos)));
 
     static USHORT pRanges[] =
     {
@@ -742,7 +745,7 @@ bool openCharDialog( const uno::Reference<report::XReportControlFormat >& _rxRep
     }
 
     SfxItemPool::Free(pPool);
-    for (sal_uInt16 i=0; i<sizeof(pDefaults)/sizeof(pDefaults[0]); ++i)
+    for (sal_uInt16 i=0; i < SAL_N_ELEMENTS(pDefaults); ++i)
         delete pDefaults[i];
 
     return bSuccess;
@@ -1082,3 +1085,5 @@ bool openDialogFormula_nothrow( ::rtl::OUString& _in_out_rFormula
 // -----------------------------------------------------------------------------
 } // namespace rptui
 // -----------------------------------------------------------------------------
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
